import { Cancellable, OnExtensionSubscriber, OnNextSubscriber, OnTerminalSubscriber, Payload, Requestable, RSocket } from "@rsocket/core";
import { Buffer } from "buffer";
export declare enum RequestType {
    REQUEST_FNF = 0,
    REQUEST_RESPONSE = 1
}
export interface Responder<I = unknown, O = unknown> {
    [RequestType.REQUEST_FNF]: (data: I) => void;
    [RequestType.REQUEST_RESPONSE]: (data: I) => O;
}
export declare class RsocketResponder implements RSocket {
    private routes;
    route<T extends keyof Responder, I = unknown, O = unknown>(path: string, handler: Responder<I, O>[T]): void;
    fireAndForget(payload: Payload, responderStream: OnTerminalSubscriber): Cancellable;
    requestChannel(payload: Payload, initialRequestN: number, isCompleted: boolean, responderStream: OnTerminalSubscriber & OnNextSubscriber & OnExtensionSubscriber & Requestable & Cancellable): OnTerminalSubscriber & OnNextSubscriber & OnExtensionSubscriber & Requestable & Cancellable;
    requestResponse(payload: Payload, responderStream: OnTerminalSubscriber & OnNextSubscriber & OnExtensionSubscriber): Cancellable & OnExtensionSubscriber;
    requestStream(payload: Payload, initialRequestN: number, responderStream: OnTerminalSubscriber & OnNextSubscriber & OnExtensionSubscriber): Requestable & Cancellable & OnExtensionSubscriber;
    metadataPush(metadata: Buffer, responderStream: OnTerminalSubscriber): void;
    cancel(): void;
    request(requestN: number): void;
    onNext(payload: Payload, isComplete: boolean): void;
    onExtension(extendedType: number, content: Buffer, canBeIgnored: boolean): void;
    onError(error: Error): void;
    onComplete(): void;
    close(error?: Error): void;
    onClose(callback: (error?: Error) => void): void;
    findHandler(metadata: Buffer | undefined): Function | undefined;
}
